@@ -16,7 +16,7 @@ class UpdateEnv(gym.Env):
     self.size = 2000     
 
     #set range for action space
-    self.high_th = np.array([4, 4, 4])
+    self.high_th = np.array([2, 2, 2])
    
     #set ACTION SPACE
     self.action_space = spaces.Box(
@@ -64,7 +64,7 @@ class UpdateEnv(gym.Env):
     patients1= np.hstack([np.ones((self.size, 1)), self.patients]) #shape (50, 3), 1st column of 1's, 2nd columns Xs, 3rd column Xa
     rho1 = (1/(1+np.exp(-(np.matmul(patients1, action[:, None])))))  #prob of Y=1  # (sizex3) x (3x1) = (size, 1)
     rho1 = rho1.squeeze() # shape: size, individual risk
-    rho1_mean =  np.mean(rho1)
+    rho1_mean =  np.mean(rho1.numpy())
 
     list1[:,0]=rho1
     rho_mean.append(rho1_mean)
